package com.ruoyi.tcZz.service;

import java.util.List;

import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcYqxxlnum;

/**
 * 舆情信息量统计Service接口
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
public interface ITcYqxxlnumService 
{
    /**
     * 查询舆情信息量统计
     * 
     * @param id 舆情信息量统计主键
     * @return 舆情信息量统计
     */
    public TcYqxxlnum selectTcYqxxlnumById(Long id);

    /**
     * 查询舆情信息量统计列表
     * 
     * @param tcYqxxlnum 舆情信息量统计
     * @return 舆情信息量统计集合
     */
    public List<TcYqxxlnum> selectTcYqxxlnumList(TcYqxxlnum tcYqxxlnum);

    /**
     * 新增舆情信息量统计
     * 
     * @param tcYqxxlnum 舆情信息量统计
     * @return 结果
     */
    public int insertTcYqxxlnum(TcYqxxlnum tcYqxxlnum);

    /**
     * 修改舆情信息量统计
     * 
     * @param tcYqxxlnum 舆情信息量统计
     * @return 结果
     */
    public int updateTcYqxxlnum(TcYqxxlnum tcYqxxlnum);

    /**
     * 批量删除舆情信息量统计
     * 
     * @param ids 需要删除的舆情信息量统计主键集合
     * @return 结果
     */
    public int deleteTcYqxxlnumByIds(Long[] ids);

    /**
     * 删除舆情信息量统计信息
     * 
     * @param id 舆情信息量统计主键
     * @return 结果
     */
    public int deleteTcYqxxlnumById(Long id);



    /**
     * 导入舆情信息量统计信息
     *
     * @return 结果
     */
    public String importUser(List<TcYqxxlnum> tcYqxxlnumList);
    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(Integer isStatus,List<String> ids);
}
