package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcYqbg;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcYqxxlnum;
import com.ruoyi.tcZz.service.ITcYqxxlnumService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 舆情信息量统计Controller
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@Api(tags = "舆情信息量统计")
@RestController
@RequestMapping("/tcZz/netWorkYq/yqxxlnum")
public class TcYqxxlnumController extends BaseController
{
    @Autowired
    private ITcYqxxlnumService tcYqxxlnumService;

    /**
     * 查询舆情信息量统计列表
     */
    @ApiOperation(value = "查询舆情信息量统计列表",response =TcYqxxlnum.class )
    @GetMapping("/list")
    public TableDataInfo list(TcYqxxlnum tcYqxxlnum)
    {
        startPage();
        List<TcYqxxlnum> list = tcYqxxlnumService.selectTcYqxxlnumList(tcYqxxlnum);
        return getDataTable(list);
    }

    /**
     * 导出舆情信息量统计列表
     */
    @ApiOperation(value = "导出舆情信息量统计列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcYqxxlnum tcYqxxlnum)
    {
        List<TcYqxxlnum> list = tcYqxxlnumService.selectTcYqxxlnumList(tcYqxxlnum);
        ExcelUtil<TcYqxxlnum> util = new ExcelUtil<TcYqxxlnum>(TcYqxxlnum.class);
        util.exportExcel(response, list, "舆情信息量统计数据");
    }

    /**
     * 获取舆情信息量统计详细信息
     */
    @ApiOperation(value = "获取舆情信息量统计详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcYqxxlnumService.selectTcYqxxlnumById(id));
    }

    /**
     * 新增舆情信息量统计
     */
    @ApiOperation(value = "新增舆情信息量统计")
    @PostMapping
    public AjaxResult add(@RequestBody TcYqxxlnum tcYqxxlnum)
    {
        return toAjax(tcYqxxlnumService.insertTcYqxxlnum(tcYqxxlnum));
    }

    /**
     * 修改舆情信息量统计
     */
    @ApiOperation(value = "修改舆情信息量统计")
    @PutMapping
    public AjaxResult edit(@RequestBody TcYqxxlnum tcYqxxlnum)
    {
        return toAjax(tcYqxxlnumService.updateTcYqxxlnum(tcYqxxlnum));
    }

    /**
     * 删除舆情信息量统计
     */
    @ApiOperation(value = "删除舆情信息量统计")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcYqxxlnumService.deleteTcYqxxlnumByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcYqxxlnum> util = new ExcelUtil<TcYqxxlnum>(TcYqxxlnum.class);
        List<TcYqxxlnum> tcYqxxlnumList = util.importExcel(file.getInputStream());
        tcYqxxlnumService.importUser(tcYqxxlnumList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcYqxxlnumService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcYqxxlnum> util = new ExcelUtil<TcYqxxlnum>(TcYqxxlnum.class);
        util.importTemplateExcel(response, " 舆情信息量统计");
    }
}
